#-
****************************************************************************
**
**  Filename:
**            Examples.frm
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Expansion of hypergeometric functions
**
**  Comments:
**
**
**  Revision: 
**            $Id: Examples.frm,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: Examples.frm,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*

#:      LargeSize   100000000
#:      SmallSize    20000000
#:      ScratchSize 100000000
#:      SortIOSize    2000000
#:      WorkSpace    10000000
#:      MaxTermSize    200000
*
#define EXPANDEP "6"
#define TRUNCEP "3"
#define MAXSUM "2"
#define MAXWEIGHT "2"
#include declvars.h
#include declsums.h

cf ln,Li;
S D,Q2; 
s CHECK;
Autodeclare S z, a, b, c;
Autodeclare CF hypergeom,appel;
CF Po,InvPo;
PolyFun, acc;

autodeclare s nu;
s s123;
Off statistics;
.global

L example1 = hypergeom2F1(a*ep,b*ep,1-c*ep,x1);
L example2 = hypergeom2F1(1,-ep,1-ep,x1);
L example3 = hypergeom3F2(-2*ep,-2*ep,1-ep,1-2*ep,1-2*ep,x1);
L example4 = appel2(1,1,ep,1+ep,1-ep,x1,x2);
*L example5 = appel1(1,ep,ep,2,x1,x2);

id hypergeom2F1(a?,b?,c?,x1?) = Po(j1+a,a)*Po(j1+b,b)*InvPo(j1+c,c)*
      sum1(j1,0,inf)*pow(x1,j1)*invfac(j1);
id hypergeom3F2(a1?,a2?,a3?,b1?,b2?,x1?) = 
      Po(j1+a1,a1)*Po(j1+a2,a2)*Po(j1+a3,a3)*InvPo(j1+b1,b1)*InvPo(j1+b2,b2)*
      sum1(j1,0,inf)*pow(x1,j1)*invfac(j1);
      
id appel1(a?,b1?,b2?,c?,x1?,x2?) = 
   Po(i1+i2+a,a)*Po(b1+i1,b1)*Po(b2+i2,b2)*InvPo(c+i1+i2,c)* 
   sum1(i1,0,inf)*pow(x1,i1)*invfac(i1)*sum2(i2,0,inf)*pow(x2,i2)*invfac(i2);
   
id appel2(a?,b1?,b2?,c1?,c2?,x1?,x2?) = 
      Po(i1+i2+a,a)*Po(i1+b1,b1)*Po(i2+b2,b2)*InvPo(i1+c1,c1)*InvPo(i2+c2,c2)*
      sum1(i1,0,inf)*pow(x1,i1)*invfac(i1)*sum2(i2,0,inf)*pow(x2,i2)*invfac(i2);

id    Po(x1?,x2?) = Gamma(x1)*InvGamma(x2);
id InvPo(x1?,x2?) = Gamma(x2)*InvGamma(x1);
   
Argument, Gamma,InvGamma;
id a = 1;
id b = 1;
id c = 1;
Endargument;   

*
* convert the sums into nested ones:
*
id  sum1(j1,0,inf) = replace_(j1,0) + sum1(j1,1,inf);  
id  sum1(i1,0,inf) * sum2(i2,0,inf) = replace_(i1,0,i2,0) 
  + sum1(j1,1,inf) * replace_(i1,0,i2,j1)
  + sum1(j1,1,inf) * replace_(i1,j1,i2,0)
  + sum1(j1,1,inf) * sum2(j2,1,j1-1) * replace_(i2,j2,i1,j1-j2);
.sort;

*
*
* call the routine for Gamma-fct expansion 
*
#call Simplify
*
*
* immediate truncation of series in ep
id ep^n0?{,>=`TRUNCEP'} = 0;
.sort: trunc eps;
*
*
* call the routine for summation 
*
#call DoSum(2,1)


repeat id pow(x1?,n1?)*pow(x1?,n2?) = pow(x1,n1+n2);
id pow(x1?,0) = 1;


SplitArg,((inf)),pow;
id pow(x?,inf) = 0;
id pow(x?,n0?,inf) = 0;
repeat id x1*den(1 - x1) = -1 + den(1 - x1);
repeat id x1*den(x1 + x2) = 1 - x2*den(x1 + x2);
repeat id 1/x1*den(x1+x2) = 1/x2*(1/x1-den(x1+x2));

#call ConvStoZ(S,Z)
id Z(R(?a),X(?x),inf) = Li(R(reverse_(?a)),X(reverse_(?x)));

Argument Li;
Argument X;
	repeat id x1*den(x1 + x2) = 1 - x2*den(x1 + x2);
	id x1^(-1)*x2 = 1/x1*num(x1+x2)-1;
	id num(x?)*den(x?) = 1;
	id x1^(-1)*x2 = 1/x1*num(x1+x2)-1;
	id num(x?) = x;
	id x1^(-1)*x2 = 1/x1*num(x1+x2)-1;
EndArgument;
EndArgument;
.sort;


*
* immediate truncation of series in ep
id acc(x?) = x;
id ep^n0?{,>`TRUNCEP'} = 0;
.sort(PolyFun=acc): trunc eps;
PolyFun;
id      acc(x?) = x;
id Li(R(?a),X(?y)) = Li(?a,?y);
B ep,den;
.sort

#append <tmp/Examples.out>
#write <tmp/Examples.out> "id example1 ="
#write <tmp/Examples.out> "      %e",example1
#write <tmp/Examples.out> "id example2 ="
#write <tmp/Examples.out> "      %e",example2
#write <tmp/Examples.out> "id example3 ="
#write <tmp/Examples.out> "      %e",example3
#write <tmp/Examples.out> "id example4 ="
#write <tmp/Examples.out> "      %e",example4

*bracket,sum,sum1,sum2,ep;
B den ep;
format,maple,120;
print +s;
.end;
*
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************
