#procedure Int2Sum(ITYPE)
****************************************************************************
**
**  Filename:
**            Int2Sum.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Procedure to express some loop integrals in terms of
**            nested sum so that they can be solved using xsummer.
**
**  Comments:
**
**
**  Revision: 
**            $Id: Int2Sum.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: Int2Sum.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*


#if `ITYPE'=="CTOPO"
***
*** Equation for the C-topology [hep-ph/0110083, eq.(87)]
***
id ctopo(?a$tescht) = ctopo(?a)*ctopo(-4711);

.sort;

G Ctopoprefac = -  pow(-1,nu12345-2*m) * 
						( InvGamma(1+ep) * InvGamma(1-ep)^2 * Gamma(1-2*ep) )^2 * 
  					Gamma(2*m-2*ep-nu1235) * Gamma(1+nu1235-2*m+2*ep) * 
						Gamma(2*m-2*ep-nu2345) * Gamma(1+nu2345-2*m+2*ep) *
  					InvGamma(nu1) * InvGamma(nu2) * InvGamma(nu3) * InvGamma(nu4) *
  					InvGamma(nu5) * InvGamma(3*m-3*ep-nu12345) *
  					Gamma(m-ep-nu5) * Gamma(m-ep-nu23) * InvGamma(2*m-2*ep-nu235 ) * 
						ctopo($tescht);

id ctopo(-4711) = ctopo(-4711) * sum1(i1,1,inf) * sum2(i2,1,inf) * 
   pow(x1,i1) * invfac(i1) * pow(x2,i2) * invfac(i2) *  
   (   
			Gamma(i1+nu3) * Gamma(i2+nu2) * Gamma(i1+i2-2*m+2*ep+nu12345 ) * 
			Gamma(i1+i2-m+ep+nu235) * InvGamma(i1+1-2*m+2*ep+nu1235) * 
			InvGamma(i2+1-2*m+2*ep+nu2345) * InvGamma(i1+i2+nu23)
   	- pow(x1,2*m-2*ep-nu1235) * Gamma(i1+2*m-2*ep-nu125) * Gamma(i2+nu2) * 
			Gamma(i1+i2+nu4)*Gamma(i1+i2+m-ep-nu1) * InvGamma(i1+1+2*m-2*ep-nu1235) * 
			InvGamma(i2+1-2*m+2*ep+nu2345) * InvGamma(i1+i2+2*m-2*ep-nu15)
		- pow(x2,2*m-2*ep-nu2345) * Gamma(i1+nu3) * Gamma(i2+2*m-2*ep-nu345) * 
			Gamma(i1+i2+nu1) * Gamma(i1+i2+m-ep-nu4) * InvGamma(i1+1-2*m+2*ep+nu1235) *
			InvGamma(i2+1+2*m-2*ep-nu2345) * InvGamma(i1+i2+2*m-2*ep-nu45)   
   	+ pow(x1,2*m-2*ep-nu1235)* pow(x2,2*m-2*ep-nu2345) * Gamma(i1+2*m-2*ep-nu125) * 
			Gamma(i2+2*m-2*ep-nu345) * Gamma(i1+i2+2* m-2* ep-nu235) * 
			Gamma(i1+i2+3*m-3*ep-nu12345) * InvGamma(i1+1+2*m-2*ep-nu1235 ) *
			InvGamma(i2+1+2*m-2*ep-nu2345) * InvGamma(i1+i2+4*m-4*ep-nu12345-nu5)
   );

Argument, Gamma,InvGamma,pow;
	id nu23    = nu2+nu3;   
	id nu15    = nu1+nu5;
	id nu45    = nu4+nu5;
	id nu125   = nu1+nu2+nu5;
	id nu235   = nu2+nu3+nu5;
	id nu345   = nu3+nu4+nu5;
	id nu1235  = nu1+nu2+nu3+nu5;
	id nu2345  = nu2+nu3+nu4+nu5;
	id nu12345 = nu1+nu2+nu3+nu4+nu5;
Endargument;   

id ctopo(n0?,...,n5?) = ctopo(m,n0,<nu1,n1>,...,<nu5,n5>);
id ctopo(m?,n0?,?a) = replace_(m,n0,?a);

#endif
#if `ITYPE' == "BBOX"
* 1 ->--------------------<- 4
*      |      nu1       |
*      |                |         with x1 = (p1+p2)^2/p4^2
*      |                |              x2 = (p2+p3)^2/p4^2
*      |nu2          nu4|
*      |                |
*      |                |
*      |      nu3       |
* 2 ->--------------------<- 3
*
*
*
* equation from hep-ph/9907523
*		eq.(2.18) for kinematical region I ( Q^2 > |s| + |t| )
*
id bbox(m?,nu1?,nu2?,nu3?,nu4?,x1?,x2?) = 
	pow(s123,nu1+nu2+nu3+nu4-m+ep)*InvGamma(1+ep)*InvGamma(1-ep)^2*Gamma(1-2*ep)*(
		+ I4q1q2(2*(m-ep),nu1,nu2,nu3,nu4,x1,x2) 
		+ I4p1p4(2*(m-ep),nu1,nu2,nu3,nu4,x1,x2)
		+ I4p4q2(2*(m-ep),nu1,nu2,nu3,nu4,x1,x2) 
		+ I4p1q1(2*(m-ep),nu1,nu2,nu3,nu4,x1,x2));

id I4q1q2(d?,nu1?,nu2?,nu3?,nu4?,x1?,x2?) =  
     pow(s123,d/2-nu1-nu2-nu3-nu4) *
     Gamma(nu1+nu2+nu3+nu4-d/2) * Gamma( d/2-nu1-nu2-nu3) * 
	Gamma(d/2-nu2-nu3-nu4) * 
     InvGamma(nu1)*InvGamma(nu4)*InvGamma(d-nu1-nu2-nu3-nu4)* 
     appel2(nu1+nu2+nu3+nu4-d/2, nu3,nu2,1+nu1+nu2+nu3 - d/2,
        1+nu2+nu3+nu4-d/2,x1,x2);

id I4p1p4(d?,nu1?,nu2?,nu3?,nu4?,x1?,x2?) = 
     pow(x1,d/2-nu1-nu2-nu3) * pow(x2,d/2-nu2-nu3-nu4) *
     pow(s123,d/2-nu1-nu2-nu3-nu4) *
     Gamma(nu1+nu2+nu3-d/2)*Gamma(nu2+nu3+nu4-d/2) * Gamma(d/2-nu1-nu2) * 
     Gamma(d/2-nu3-nu4)*Gamma(d/2-nu2-nu3) *
     InvGamma(nu1)*InvGamma(nu2)*InvGamma(nu3)*InvGamma(nu4)*
			InvGamma(d-nu1-nu2-nu3-nu4) *
     appel2(d/2-nu2-nu3,d/2-nu1-nu2,d/2-nu3-nu4,1+d/2-nu1-nu2-nu3,
        1+d/2-nu2-nu3-nu4,x1,x2);
   
id I4p4q2(d?,nu1?,nu2?,nu3?,nu4?,x1?,x2?) = 
     pow(x1,d/2-nu1-nu2-nu3) * pow(s123,d/2-nu1-nu2-nu3-nu4) *
     Gamma(nu1+nu2+nu3-d/2) * Gamma(d/2-nu1-nu2) * Gamma(d/2-nu2-nu3-nu4) *
     InvGamma(nu1)*InvGamma(nu3)*InvGamma(d-nu1-nu2-nu3-nu4) *
     appel2(nu4,d/2-nu1-nu2,nu2,1+d/2-nu1-nu2-nu3,1+nu2+nu3+nu4-d/2,x1,x2);

id I4p1q1(d?,nu1?,nu2?,nu3?,nu4?,x1?,x2?) =  
     pow(x2,d/2-nu2-nu3-nu4) * pow(s123,d/2-nu1-nu2-nu3-nu4) *
     Gamma(nu2+nu3+nu4-d/2)*Gamma(d/2-nu1-nu2-nu3)*Gamma(d/2-nu3-nu4) *
     InvGamma(nu2) * InvGamma(nu4) * InvGamma(d-nu1-nu2-nu3-nu4)  * 
     appel2(nu1,nu3,d/2-nu3-nu4,1+nu1+nu2+nu3-d/2,1+d/2-nu2-nu3-nu4,x1,x2);

id appel2(a?,b1?,b2?,c1?,c2?,x1?,x2?) = 
      Po(i1+i2+a,a)*Po(i1+b1,b1)*Po(i2+b2,b2)*InvPo(i1+c1,c1)*InvPo(i2+c2,c2)*
      sum1(i1,0,inf)*pow(x1,i1)*invfac(i1)*sum2(i2,0,inf)*pow(x2,i2)*invfac(i2);
#endif

#if ((`ITYPE' == "TRIZERO") || (`ITYPE' == "TRIMASS"))
*
*  $Id: Int2Sum.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
*
*
*  1 ->------\
*       |     \ nu2
*       |      \ 
*       |       \ 
*       |nu3     --<- 3    
*       |       / 
*       |      / 
*       |     / nu1
*  2 ->------/
*
*
id Tri1(d?,nu1?,nu2?,nu3?) = puretri(2*d-2*ep,nu2,nu3,nu1);
id Tri3(d?,nu1?,nu2?,nu3?) = scaletri(2*d-2*ep,nu1,nu2,nu3,x1);

*
* normalized massless triangle 
*
*
* equation from hep-ph/9907494
*               eq.(3.11) 
*
id puretri(D?,nu1?,nu2?,nu3?) 
          = InvGamma(1+ep)*InvGamma(1-ep)^2*Gamma(1-2*ep)*
            Gamma(nu1+nu2+nu3-D/2)*Gamma(D/2-nu1-nu2)*Gamma(D/2-nu1-nu3)*
            InvGamma(nu2)*InvGamma(nu3)*InvGamma(D-nu1-nu2-nu3);

*
* normalized one scale triangle 
*
*
* equation from hep-ph/9907494
*               eq.(3.9) 

id scaletri(D?,nu1?,nu2?,nu3?,x1?) 
      = InvGamma(1+ep)*InvGamma(1-ep)^2*Gamma(1-2*ep)*
        (
        Gamma(D/2-nu1-nu2)*Gamma(D/2-nu1-nu3)*Gamma(nu1+nu2+nu3-D/2)*
        InvGamma(nu2)*InvGamma(nu3)*InvGamma(D-nu1-nu2-nu3)*
        hypergeom2F1(nu1,nu1+nu2+nu3-D/2,1+nu1+nu3-D/2,x1)
        +
        pow(x1,D/2-nu1-nu3)*
        Gamma(D/2-nu1-nu2)*Gamma(D/2-nu3)*Gamma(nu1+nu3-D/2)*
        InvGamma(nu1)*InvGamma(nu3)*InvGamma(D-nu1-nu2-nu3)*
        hypergeom2F1(nu2,D/2-nu3,1+D/2-nu1-nu3,x1)
        );

id hypergeom2F1(a?,b?,c?,x1?) = Po(j1+a,a)*Po(j1+b,b)*InvPo(j1+c,c)*
      sum1(j1,0,inf)*pow(x1,j1)*invfac(j1);

#endif


*
* Replace the Pochhammer functions by Gamma functions:
*
id    Po(x1?,x2?) = Gamma(x1)*InvGamma(x2);
id InvPo(x1?,x2?) = Gamma(x2)*InvGamma(x1);

repeat id pow(x?,n1?)*pow(x?,n2?) = pow(x,n1+n2);

*
* Convert the sums into nested ones:
*
#switch `ITYPE' 
	#case CTOPO
		id  sum1(i1,1,inf) * sum2(i2,1,inf) = replace_(i1,0,i2,0) 
  		+ sum1(j1,1,inf) * replace_(i1,0,i2,j1)
  		+ sum1(j1,1,inf) * replace_(i1,j1,i2,0)
  		+ sum1(j1,1,inf) * sum2(j2,1,j1-1) * replace_(i2,j2,i1,j1-j2);
	#break
	#case BBOX
		id  sum1(i1,0,inf) * sum2(i2,0,inf) = replace_(i1,0,i2,0) 
  		+ sum1(j1,1,inf) * replace_(i1,0,i2,j1)
  		+ sum1(j1,1,inf) * replace_(i1,j1,i2,0)
  		+ sum1(j1,1,inf) * sum2(j2,1,j1-1) * replace_(i2,j2,i1,j1-j2);
	#break
  #case TRIZERO
  #case TRIMASS
		id  sum1(i1,0,inf) * sum2(i2,0,inf) = replace_(i1,0,i2,0) 
  		+ sum1(j1,1,inf) * replace_(i1,0,i2,j1)
  		+ sum1(j1,1,inf) * replace_(i1,j1,i2,0)
  		+ sum1(j1,1,inf) * sum2(j2,1,j1-1) * replace_(i2,j2,i1,j1-j2);
	#break
#endswitch

*
* Do a few trivial simplifications:
*
repeat id pow(x?,n1?)*pow(x?,n2?) = pow(x,n1+n2);
id pow(x1?,0) = 1;
id pow(x1?number_,n0?pos0_) = x1^n0;
id pow(x?,n0?neg_) = den(x)^(-n0);

id Gamma(n0?pos_) = fac_(n0-1);
id InvGamma(n0?pos_) = invfac_(n0-1);
id InvGamma(2) = 1;
id invfac(n0?number_) = invfac_(n0);

#endprocedure
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************
