#procedure AlgB(i)
****************************************************************************
**
**  Filename:
**            AlgB.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Implementation of the convolution algorithm (type B) to perform sums 
**            of the type
**            \begin{displaymath}
**                \sum\limits_{i=1}^{n-1} 
**                {x_1^i \over i^{m_1}} S(i;m_2,...,m_k;x_2,...,x_k) 
**                {(x^{\prime}_1)^{n-i} \over (n-i)^{m^{\prime}_1}} 
**                S(n-i;m^{\prime}_2,...,m^{\prime}_l;
**									x^{\prime}_2,...,x^{\prime}_l)\, ,
**            \end{displaymath}
**            for any (integer) values of $m_i, m_i^\prime$ and  $m_1>0$.
**            The argument specifies 
**            the index $i$ of the sum to be done.
**            The special case $m_1=0$ is handled in \keyword{AlgB0}.
**
**
**  Comments:
**
**
**  Revision: 
**            $Id: AlgB.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: AlgB.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*
if ( count(den`i',1) == 1 );
	if ( count(S`i',1) == 2 ); 
		if ( count(pow`i',1) == 1 );
			id  sum`i'(j`i',1,n?)*S`i'(R(?a),X(?x),x1?,-j`i')*S`i'(R(?b),X(?y),0,j`i')*
				pow`i'(y1?,j`i')*den`i'(k?,0,j`i') = 
				SAlgBS(R(?a),X(?x),R(?b),X(?y),y1,k,n,x1);
		else;
			id sum`i'(j`i',1,n?)*S`i'(R(?a),X(?x),x1?,-j`i')*S`i'(R(?b),X(?y),0,j`i')*
				den`i'(k?,0,j`i') = 
				SAlgBS(R(?a),X(?x),R(?b),X(?y),1,k,n,x1);
		endif;
	elseif ( count(S`i',1) == 1 );
		if ( count(pow`i',1) == 1 );
			id sum`i'(j`i',1,n?)*S`i'(R(?a),X(?x),x1?,-j`i')*
				pow`i'(y1,j`i')*den`i'(k?,0,j`i') = SAlgBS(R(?a),X(?x),R,X,y1,k,n,x1);
  	else;
      id sum`i'(j`i',1,n?)*S`i'(R(?a),X(?x),x1?,-j`i')*
				den`i'(k?,0,j`i') = SAlgBS(R(?a),X(?x),R,X,1,k,n,x1);
 	  endif;
	endif;
		id SAlgBS(?a,n?,n?) = SAlgBS(?a,n);
    id SAlgBS(R(?a),X(?x),R(?b),X(?y),1,k?,n?,x1?) = sum`i'(j`i',1,n)*
				S`i'(R(?a),X(?x),x1,-j`i')*S`i'(R(?b),X(?y),0,j`i')*
				den`i'(0,j`i')^k;
    id SAlgBS(R(?a),X(?x),R(?b),X(?y),y1?,k?,n?,x1?) = sum`i'(j`i',1,n)*
				S`i'(R(?a),X(?x),x1,-j`i')*S`i'(R(?b),X(?y),0,j`i')*
				pow`i'(y1,j`i')*den`i'(0,j`i')^k;
endif;
*
*   - sums this routine can handle are now in the function SAlgBS:
*			* add pairs of x1,k,n if there are new denominators and 
*	  summations boundaries.
*   	* eventually hit on sums that can be done and then work 
*	  backwards 
*
repeat id SAlgBS(R(n1?,?a),X(x1?,?x),R(?b),X(?y),y1?,k?,?c) =
				+sum_(jjj,1,k,SAlgBS(R(?a),X(?x),R(?b),X(?y),y1/x1,jjj,x1,k+n1-jjj,?c)*
					binom_(k+n1-1-jjj,n1-1))
        +sum_(jjj,1,n1,SAlgBS(R(?b),X(?y),R(?a),X(?x),x1/y1,jjj,y1,k+n1-jjj,?c)*
					binom_(k+n1-1-jjj,k-1));
id SAlgBS(R,X,R(?b),X(?y),y1?,k?,x1?,m?,?c,n?) = 
		SAlgBS(R,X,R(k,?b),X(y1,?y),x1,m,?c,n) - SAlgBS(R,X,R(?b),X(?y),x1*y1,m+k,?c,n);
repeat id SAlgBS(R,X,R(?b),X(?y),y1?,n1?,?c,n?) = SAlgBS(R,X,R(n1,?b),X(y1,?y),?c,n);
id SAlgBS(R,X,R(?b),X(?y),n?) = S(R(?b),X(?y),n);
#endprocedure
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************
