#procedure NormDen(ndi)
****************************************************************************
**
**  Filename:
**            NormDen.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Converts \keyword{den} functions to normal form, i.e. fixes 
**            the sign of the summation index appearing in the 
**            denominator. The argument specifies the highest summation index 
**            $i$ to be treated. The hierarchy is such that $j_1$ is more 
**            important than $j_2$ etc. 
**
**  Comments:
**            We use f1 as a auxiliary for functions that have the 
**            proper sign already.
**
**  Revision: 
**            $Id: NormDen.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: NormDen.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*
#do ndii = 1,`ndi'-1
if ( count(den`ndi',1) );
    SplitArg,(j`ndii'),den`ndi';
    id  den`ndi'(j`ndii',x1?) = f1(j`ndii',x1);
    id  den`ndi'(-j`ndii',x1?) = -f1(j`ndii',-x1);
    id  den`ndi'(x2?,j`ndii',x1?) = f1(x2+j`ndii',x1);
    id  den`ndi'(x2?,-j`ndii',x1?) = -f1(-x2+j`ndii',-x1);
#enddo
    id  den`ndi'(x1?,-j`ndi') = -den`ndi'(-x1,j`ndi');
#do ii = 1,`ndi'-1
endif;
#enddo
id  f1(?a) = den`ndi'(?a);
#endprocedure
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************