#procedure NormalizeGam
****************************************************************************
**
**  Filename:
**            NormalizeGam.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Normalizes products of \keyword{Gamma} and \keyword{InvGamma} 
**            functions.
**
**  Comments:
**            We define
**              G(a*ep) = Gamma(1+a*ep)
**              InvG(a*ep) = 1/Gamma(1+a*ep)
**
**            and (assuming 0 < x 1 rational)
**            Gpq(x,a*ep) = Gamma(x+a*ep)
**            InvGpq(x,a*ep) = 1/Gamma(x+a*ep)
**
**  Revision: 
**            $Id: NormalizeGam.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: NormalizeGam.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*
*
* Gamma(n?int_+a*ep) = deltap_(a)*G(a*ep)
*		        +delta_(a)*theta(n-1)*fac_(n-1);
* InvGamma(n?int_+a*ep) = deltap_(a)*InvG(a*ep)
*			+delta_(a)*theta(n-1)*invfac_(n-1);
*
*
*
* (1) rewrite all Gamma() without ep-dependence to factorials
*
SplitArg,((ep)),Gamma,InvGamma;
id	Gamma(ep) = Gamma(0,ep);
id	InvGamma(ep) = InvGamma(0,ep);
id	Gamma(x?) = fac(x-1);
id	InvGamma(x?) = invfac(x-1);
id	Gamma(x1?,x2?) = Gamma(x1+x2);
id	InvGamma(x1?,x2?) = InvGamma(x1+x2);

id	InvGamma(x?)*Gamma(x?) = 1; 
id	fac(x?)*invfac(x?) = 1;
id	fac(x?number_) = fac_(x);
id	invfac(x?number_) = invfac_(x);

SplitArg,((ep)),Gamma,InvGamma;

*
* (2) normalization of Gamma(n+a*ep) with n integer
*
id	Gamma(ep) = Gamma(0,ep);
id	InvGamma(ep) = InvGamma(0,ep);
id	Gamma(0,x?) = Gammaa(x/ep,x);
id	InvGamma(0,x?) = InvGammaa(x/ep,x);
id	Gammaa(x?,ep?) = G(ep)*epow(-1)/x;
id	InvGammaa(x?,ep?) = x*epow(1)*InvG(ep);
id	G(x?)*InvG(x?) = 1;
repeat id epow(n1?)*epow(n2?) = epow(n1+n2);
id      epow(0) = 1;

id	Gamma(n?int_,ep?) = X(n,ep);
repeat;
	id	X(1,x?) = G(x);
	id	X(n?pos_,x?) = num(n-1+x)*X(n-1,x);
	id	X(n?neg_,x?) = den(n+x)*X(n+1,x);
	id	X(0,x?) = den(x)*G(x);
endrepeat;
id	InvGamma(n?int_,ep?) = X(n,ep);
repeat;
	id	X(1,x?) = InvG(x);
	id	X(n?pos_,x?) = den(n-1+x)*X(n-1,x);
	id	X(n?neg_,x?) = num(n+x)*X(n+1,x);
	id	X(0,x?) = num(x)*InvG(x);
endrepeat;
id	G(x?)*InvG(x?) = 1;
id	num(x?)*den(x?) = 1;

SplitArg,((ep)),num,den;
id 	den(0,x?) = dena(x/ep,x);
id	num(0,x?) = numa(x/ep,x);
id	dena(x?,ep?) = epow(-1)/x;
id	numa(x?,ep?) = epow(1)*x;
id	den(x?,ep?) = den(x+ep);
id	num(x?,ep?) = num(x+ep);
id	num(x?)*den(x?) = 1;
repeat 	id epow(n1?)*epow(n2?) = epow(n1+n2);

*
* (3) normalization of Gamma(p/q+a*ep) with p,q integer
*
id	Gamma(n?number_,ep?) = X(sig_(n),n,ep);
repeat 	id	X(+1,n?number_,x?) = num(n-1+x)*X(sig_(n-1),n-1,x);
repeat 	id	X(-1,n?number_,x?) = den(n+x)*X(sig_(n+1),n+1,x);
id 	X(1,n?number_,x?) = Gpq(n,x);
id	InvGamma(n?number_,ep?) = X(sig_(n),n,ep);
repeat	id	X(+1,n?number_,x?) = den(n-1+x)*X(sig_(n-1),n-1,x);
repeat	id	X(-1,n?number_,x?) = num(n+x)*X(sig_(n+1),n+1,x);
id 	X(1,n?number_,x?) = InvGpq(n,x);
id	Gpq(n?,x?)*InvGpq(n?,x?) = 1;
id	num(x?)*den(x?) = 1;

id 	invfac_(n?) = invfac_(n)*theta_(n);
id	theta_(x?) = theta(x);
.sort(PolyFun=acc):Gamma(const);
id	delta_(x?) = delta(x);
id	deltap_(x?) = deltap(x);

#endprocedure
*
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************
